@@ -7,10 +7,10 @@ module Neovim
   class RemoteObject
     attr_reader :index
 
-    def initialize(index, session)
+    def initialize(index, session, api)
       @index = index
       @session = session
-      @api = session.api
+      @api = api
     end
 
     # Serialize object to MessagePack.
@@ -23,20 +23,20 @@ module Neovim
 
     # Intercept method calls and delegate to appropriate RPC methods.
     def method_missing(method_name, *args)
-      if func = @api.function(qualify(method_name))
+      if (func = @api.function_for_object_method(self, method_name))
         func.call(@session, @index, *args)
       else
         super
       end
     end
 
-    # Extend +respond_to?+ to support RPC methods.
-    def respond_to?(method_name)
+    # Extend +respond_to_missing?+ to support RPC methods.
+    def respond_to_missing?(method_name, *)
       super || rpc_methods.include?(method_name.to_sym)
     end
 
     # Extend +methods+ to include RPC methods
-    def methods
+    def methods(*args)
       super | rpc_methods
     end
 
@@ -48,17 +48,7 @@ module Neovim
     private
 
     def rpc_methods
-      @api.functions_with_prefix(function_prefix).map do |func|
-        func.name.sub(/\A#{function_prefix}/, "").to_sym
-      end
-    end
-
-    def function_prefix
-      "#{self.class.to_s.split("::").last.downcase}_"
-    end
-
-    def qualify(method_name)
-      :"#{function_prefix}#{method_name}"
+      @api.functions_for_object(self).map(&:method_name)
     end
   end
 end
