@@ -13,23 +13,23 @@ module Neovim
 
     describe ".current" do
       it "returns the current buffer from the global Vim client" do
-        expect(Buffer.current).to eq(nvim.get_current_buffer)
+        expect(Buffer.current).to eq(nvim.get_current_buf)
       end
     end
 
     describe ".count" do
       it "returns the current buffer count from the global Vim client" do
-        expect {
+        expect do
           nvim.command("new")
-        }.to change { Buffer.count }.by(1)
+        end.to change { Buffer.count }.by(1)
       end
     end
 
     describe ".[]" do
       it "returns the buffer from the global Vim client at the given index" do
-        expect(Buffer[0]).to eq(nvim.get_current_buffer)
+        expect(Buffer[0]).to eq(nvim.get_current_buf)
         nvim.command("new")
-        expect(Buffer[1]).to eq(nvim.get_current_buffer)
+        expect(Buffer[1]).to eq(nvim.get_current_buf)
       end
     end
   end
